@@ -15,6 +15,40 @@
 
 #include <iconv.h>
 
+#define CCONV_CODE_UTF  "UTF-8"
+
+// GBL means LARGEST of GB encoding.
+#define CCONV_CODE_GBL  "GB18030"
+#define CCONV_CODE_BIG  "BIG5"
+
+#define CCONV_CODE_UCN  "UTF8-CN"
+#define CCONV_CODE_UTW  "UTF8-TW"
+#define CCONV_CODE_UHK  "UTF8-HK"
+
+#define CCONV_CODE_UHS  "UTF8-HANS"
+#define CCONV_CODE_UHT  "UTF8-HANT"
+
+#define CCONV_CODE_GHS  "GB-HANS"
+#define CCONV_CODE_GHT  "GB-HANT"
+
+typedef enum cconv_type
+{
+	CCONV_ERROR = -1,
+	CCONV_NULL  = 0 ,
+	CCONV_GBL_TO_BIG = 1,
+	CCONV_GBL_TO_UHS,
+	CCONV_GBL_TO_UHT,
+	CCONV_GBL_TO_GHS,
+	CCONV_GBL_TO_GHT,
+	CCONV_BIG_TO_GBL,
+	CCONV_BIG_TO_UHS,
+	CCONV_UTF_TO_UHT,
+	CCONV_UTF_TO_UHS,
+	CCONV_UTF_TO_GBL,
+	CCONV_UTF_TO_BIG,
+}
+cconv_type;
+
 typedef void* cconv_t;
 
 /* {{{ cconv_t cconv_open(const char* tocode, const char* fromcode) */
